package com.zhilian.business.service.impl;

import com.zhilian.business.domain.BreakLog;
import com.zhilian.business.mapper.BreakLogMapper;
import com.zhilian.business.service.BreakLogService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.data.redis.RedisProperties;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @ClassName BreakLogServiceImpl
 * @Description 定时扫描故障状态
 * @Author YuanYongH
 * @Date 2024/4/8 20:49
 */
@Service
@Log4j2
public class BreakLogServiceImpl implements BreakLogService {
    @Autowired
    private BreakLogMapper breakLogMapper;

    @Autowired
    private RedisTemplate<String ,String> redisTemplate;


    @Override
    public List<BreakLog> breakLog() {
        BreakLog breakLog = new BreakLog();
        // 10秒
        final long timeInterval = 10000;
        Runnable runnable = new Runnable() {
            @Override
            public void run() {
                while (true){
                    breakLogMapper.breakLog();
                    log.info("扫描故障状态");
                    String breakState = breakLog.getBreakState();
                    if (breakState != null){
                        // 判断故障状态
                        if (breakLog.getBreakState().equals("0")){
                            log.info("正常");
                        }else if (breakLog.getBreakState().equals("1")){
                            log.info("故障");
                        }else {
                            log.info("未知");
                        }

                    }
                    try {
                        Thread.sleep(timeInterval);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }
            }
        };
        // 开启线程
        Thread thread = new Thread(runnable);
        thread.start();
        // 返回故障日志
        return breakLogMapper.breakLog();
    }
}
